pub struct JsonKeyValueMap(/* private fields */);Expand description
Struct used to safely exchange data in json format in plugins. It is not entirely abi stable due to using String, but should do for now since we require plugins to use the same version of rustc and same version of zenoh.
Implementations
Sourceimpl JsonKeyValueMap
impl JsonKeyValueMap
pub fn into_serde_map(&self) -> Map<String, Value>