TimeExpr

Enum TimeExpr 

pub enum TimeExpr {
    Fixed(SystemTime),
    Now {
        offset_secs: f64,
    },
}

Variants



Fixed(SystemTime)



Now

Fields

offset_secs: f64

Implementations

Source

impl TimeExpr

pub fn resolve_at(&self, now: SystemTime) -> SystemTime

Resolves self into a SystemTime, using now as a reference for offset expressions.

Panics

This function may panic if the resulting point in time cannot be represented by the underlying data structure. See TimeExpr::checked_resolve_at for a version without panic.

pub fn checked_resolve_at(&self, now: SystemTime) -> Option<SystemTime>

Resolves self into a SystemTime, using now as a reference for offset expressions. If self is a TimeExpr::Now{offset_secs} and adding offset_secs to now results in a time that would be outside the bounds of the underlying data structure, None is returned.

pub fn checked_add(&self, duration: f64) -> Option<Self>

Adds duration to self, returning None if self is a Fixed(SystemTime) and adding the duration is not possible because the result would be outside the bounds of the underlying data structure (see SystemTime::checked_add). Otherwise returns Some(time_expr).

pub fn checked_sub(&self, duration: f64) -> Option<Self>

Subtracts duration from self, returning None if self is a Fixed(SystemTime) and subtracting the duration is not possible because the result would be outside the bounds of the underlying data structure (see SystemTime::checked_sub). Otherwise returns Some(time_expr).