TimeRange

Struct TimeRange 

pub struct TimeRange<T = TimeExpr> {
    pub start: TimeBound<T>,
    pub end: TimeBound<T>,
}
The structural representation of the Zenoh Time DSL, which may adopt one of two syntax:

  • the “range” syntax: <ldel: '[' | ']'><start: TimeExpr?>..<end: TimeExpr?><rdel: '[' | ']'>
  • the “duration” syntax: <ldel: '[' | ']'><start: TimeExpr>;<duration: Duration><rdel: '[' | ']'>, which is equivalent to <ldel><start>..<start+duration><rdel>

Durations follow the <duration: float><unit: "u", "ms", "s", "m", "h", "d", "w"> syntax.

Where TimeExpr itself may adopt one of two syntaxes:

  • the “instant” syntax, which must be a UTC RFC3339 formatted timestamp.
  • the “offset” syntax, which is written now(<sign: '-'?><offset: Duration?>), and allows to specify a target instant as an offset applied to an instant of evaluation. These offset are resolved at the evaluation site.

In range syntax, omitting <start> and/or <end> implies that the range is unbounded in that direction.

Exclusive bounds are represented by their respective delimiters pointing towards the exterior. Interior bounds are represented by the opposite.

The comparison step for instants is the nanosecond, which makes exclusive and inclusive bounds extremely close. The [<start>..<end>[ pattern may however be useful to guarantee that a same timestamp never appears twice when iteratively getting values for [t0..t1[, [t1..t2[, [t2..t3[

Fields

start: TimeBound<T>end: TimeBound<T>

Implementations

Source

impl TimeRange<TimeExpr>

pub fn resolve_at(self, now: SystemTime) -> TimeRange<SystemTime>

Resolves the offset bounds in the range using now as reference.

pub fn resolve(self) -> TimeRange<SystemTime>

Resolves the offset bounds in the range using SystemTime::now as reference.

pub fn contains(&self, instant: SystemTime) -> bool

Returns true if the provided instant belongs to self.

This method performs resolution with SystemTime::now if the bounds contain an “offset” time expression. If you intend on performing this check multiple times, it may be wiser to resolve self first, and use TimeRange::<SystemTime>::contains instead.

Source

impl TimeRange<SystemTime>

pub fn contains(&self, instant: SystemTime) -> bool

Returns true if the provided instant belongs to self.